<?php

namespace App\Http\Controllers\Api\V1;

use Illuminate\Http\Request;
use App\Http\Resources\CompetitorProductResource;
use App\Http\Controllers\Controller;
use App\CompetitorProduct;

class CompetitorProductsController extends Controller
{
    /**
     * Gets a single competitor product
     *
     * @return Competitor Product Object
     * @author mattsidjohn
    **/
    public function get(CompetitorProduct $competitorProduct)
    {
        return new CompetitorProductResource(
            $competitorProduct->with('competitor')
                ->where('id', $competitorProduct->id)
                ->get()
        );
    }

    /**
     * Get all competitor products
     *
     * @return Competitor Products Object
     * @author mattsidjohn
     **/
    public function getAll()
    {
        return new CompetitorProductResource(
            CompetitorProduct::with('competitor')->get()
        );
    }

    /**
     * Store new competitor product.
     *
     * @return New Competitor Product Object
     * @author mattsidjohn
     **/
    public function store(Request $request)
    {
        // Create the new competitor
        $competitorProduct = CompetitorProduct::create($request->all());

        return new CompetitorProductResource($competitorProduct);
    }

    /**
     * Destroy the specified Competitor
     *
     * @return boolean
     * @author mattsidjohn
     **/
    public function destroy(CompetitorProduct $competitorProduct)
    {
        try {
            // Delete the competitor
            $competitorProduct->delete();

            return response('Success!', 200);
        } catch (Exception $e) {
            return response($e->getMessage, $e->code);
        }
    }
}
