<?php

namespace App\Http\Controllers;

use App\User;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Facades\Hash;

class UsersController extends Controller
{
    public function index()
    {
        $this->authorize('view user');
        return view('users.index', ['users' => User::get()]);
    }

    public function create(Request $request)
    {
        $this->authorize('create user');
        return view('users.create', ['roles' => Role::where('name', '!=', 'super admin')->get()->pluck('name', 'id')]);
    }

    public function store(Request $request)
    {
        $this->authorize('create user');
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
        ]);
        $user->assignRole($request->role);
        return redirect()->back()->with('success', 'User was created!');
    }

    public function edit(User $user)
    {
        $this->authorize('create user');
        $roles = Role::where('name', '!=', 'super admin')->get()->pluck('name', 'id');

        $relateableRole = ($user->hasRole('sales manager'))
            ? 'sales rep'
            : 'sales manager';

        $relatedUsersIds = ($relateableRole == 'sales rep')
            ? $user->salesReps->pluck('id')->toArray()
            : $user->salesManagers->pluck('id')->toArray();

        return view('users.edit', ([
            'user' => $user,
            'relatableUsers' => User::role($relateableRole)
                ->where('id', '!=', $user->id)
                ->get(),
            'roles' => $roles,
            'relatedUsersIds' => $relatedUsersIds
        ]));
    }

    public function update(Request $request, User $user)
    {
        $this->authorize('create user');
        if ($request->password == null) {
            unset($request['password']);
            unset($request['password_confirmation']);
        } else {
            $user->password = Hash::make($request->password);
            $user->update();
            unset($request['password']);
            unset($request['password_confirmation']);
        }

        $user->update($request->all());
        $user->syncRoles($request->role);
        return redirect()->back()->with('success', $user->name . ' was successfuly updated.');
    }
    
    public function destroy($user)
    {
        $this->authorize('create user');
        $user = User::find($user);
        $user->delete();
        return redirect()->route('users.index')->with('success', 'The user has been deleted successfully!');
    }
}
