<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use App\ProductCategory;

class Product extends Model
{
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'ee_product_id',
        'name',
        'description',
        'additional_information',
        'excerpt',
        'specifications',
        'colors'
    ];

    /**
     * Function to return an product categories
     *
     * @return object of categories
     * @author mattsidjohn
     **/
    public function categories()
    {
        return $this->belongsToMany(
            ProductCategory::class,
            'products_product_categories',
            'product_id',
            'category_id'
        );
    }

    /**
     * Function to return related products
     *
     * @return object of products
     * @author mattsidjohn
     **/
    public function items()
    {
        return $this->hasMany(
            ProductItem::class,
            'product_id'
        );
    }

    /**
     * Function to return related products
     *
     * @return object of products
     * @author mattsidjohn
     **/
    public function variations()
    {
        return $this->hasMany(
            ProductVariation::class,
            'product_id'
        );
    }

    /**
     * Cross reference relationships
     *
     * @return Competitor Product object
     * @author mattsidjohn
     **/
    public function crossReference()
    {
        return $this->belongsToMany(
            CompetitorProduct::class,
            'products_competitor_products',
            'competitor_product_id'
        );
    }

    // Accessors

    /**
     * Unserializes the Colors
     *
     * @return Array of Colors
     * @author mattsidjohn
     **/
    public function getColorsAttribute($value)
    {
        return unserialize($value);
    }
}
