<?php

namespace App\Services\Api;

use Auth;
use Illuminate\Http\Request;
use App\Http\Resources\UserResource;
use Illuminate\Support\Facades\DB;

class AuthorizeUser
{
    public function __construct(Request $request)
    {
        $this->request = $request;
        $this->http = new \GuzzleHttp\Client;
        $this->client = DB::table('oauth_clients')->where('password_client', 1)->first();
    }

    public function handle()
    {
        return $this->getToken();
    }

    private function getToken()
    {
        // Check to see if login attempt passes
        if (Auth::attempt($this->request->only(['email', 'password']))) {
            // Check for access token stored to the user and create one if it doesn't
            if (! Auth::user()->access_token) {
                // Create Auth token
                $response = $this->http->post(env('APP_URL') . '/oauth/token', [
                    'form_params' => [
                        'grant_type' => 'password',
                        'client_id' => $this->client->id,
                        'client_secret' => $this->client->secret,
                        'username' => $this->request->email,
                        'password' => $this->request->password,
                        'scope' => '*',
                    ],
                ]);

                // Decode response
                $body = json_decode((string) $response->getBody(), true);

                // Store the token to the user.
                if ($body['access_token']) {
                    Auth::user()->access_token = $body['access_token'];
                    Auth::user()->save();
                }
            }

            // Retun user access token.
            return new UserResource(collect(['bearer' => Auth::user()->access_token]));
        } else {
            return response('Unauthenticated.', 401);
        }
    }
}
